<?php
/**
 * Plugin Name: Stames Floating Widget
 * Plugin URI: https://www.stamesoft.com/resources
 * Description: A plugin to embed the Stames Floating Web Widget with Call-to-Action and One-Click options.
 * Version: 1.0.0
 * Author: Stames Software
 * Author URI: https://www.stamesoft.com
 * License: GPL2
 */

// Prevent direct file access
if (!defined('ABSPATH')) {
    exit;
}

// Register settings
function stames_floating_register_settings() {
    register_setting('stames_floating_settings_group', 'stames_floating_data_key', 'sanitize_text_field');
    register_setting('stames_floating_settings_group', 'stames_floating_widget_type', 'sanitize_text_field');
}
add_action('admin_init', 'stames_floating_register_settings');

// Enqueue Scripts & jQuery
function stames_floating_enqueue_scripts() {
    $data_key = esc_attr(get_option('stames_floating_data_key', 'default-key'));
    $widget_type = esc_attr(get_option('stames_floating_widget_type', 'cta'));

    // Ensure jQuery is loaded from WordPress Core
    wp_enqueue_script('jquery');

    // Determine the correct widget script (local file)
    $script_filename = ($widget_type === 'cta') ? 'stamescta_20210417181738.min.js' : 'stamesco_20210417181738.min.js';
    $script_url = plugins_url('assets/js/' . $script_filename, __FILE__);
	
	// Register and enqueue the Stames widget script
	wp_register_script('stames-widget', $script_url, array('jquery'), null, true);
	wp_enqueue_script('stames-widget');

    // Register and enqueue the widget script
    //wp_register_script('stames-widget', $script_url, array('jquery'), null, true);
    //wp_enqueue_script('stames-widget');

    // Pass the Data Key to JavaScript
    wp_localize_script('stames-widget', 'stamesWidgetData', array(
        'dataKey' => esc_attr($data_key),
    ));
}
add_action('wp_enqueue_scripts', 'stames_floating_enqueue_scripts');

// Inject Stames widget HTML into the footer
function stames_floating_output_widget() {
    $data_key = esc_attr(get_option('stames_floating_data_key', 'default-key'));
    echo '<!-- Start Stames Tag -->';
    echo '<stames-app data-key="' . esc_attr($data_key) . '"></stames-app>';
    echo '<!-- End Stames Tag -->';
}
add_action('wp_footer', 'stames_floating_output_widget');

// Plugin settings page
function stames_floating_menu() {
    add_management_page('Stames Floating Widget Settings', 'Stames Floating Widget', 'manage_options', 'stames-floating-widget', 'stames_floating_settings_page');
    add_submenu_page('stames-floating-widget', 'Instructions', 'Instructions', 'manage_options', 'stames-floating-instructions', 'stames_floating_instructions_page');
}
add_action('admin_menu', 'stames_floating_menu');

function stames_floating_settings_page() {
    ?>
    <div class="wrap">
        <div style="margin-bottom: 0px;">
            <a href="https://www.stamesoft.com" target="_blank">
                <img src="<?php echo esc_url(plugin_dir_url(__FILE__)) . 'assets/stames-logo.png'; ?>" alt="Stames Logo" style="max-width: 80px;">
            </a>
        </div>
        <h1>Stames Floating Widget Settings</h1>
        <form method="post" action="options.php">
            <?php settings_fields('stames_floating_settings_group'); ?>
            <?php do_settings_sections('stames_floating_settings_group'); ?>
			<p class="desc">
				In today’s fast-paced digital world, businesses are flooded with messages from multiple platforms—WhatsApp, Instagram, Facebook, Emails, Contact Forms and more. <strong>The challenge?</strong> Missed messages, lost leads, and scattered customer data that slow down sales and hurt customer experience.

				That’s where Stames comes in.
			</p>
				<p class="desc">
				<strong>What is Stames?</strong><br>
				Stames is a cutting-edge 360° SaaS communication and automation platform that centralizes, tracks, and streamlines customer interactions across multiple channels—helping businesses stay on top of every conversation, every lead, and every sale. Unlike traditional CRM systems or customer service tools that only focus on one part of the problem, Stames unifies communication, automates workflows, and provides deep insights—helping businesses increase sales, improve customer retention, and scale effortlessly. <br><br>
				
				Stames Web Widgets are powerful floating call-to-action (CTA) buttons that seamlessly integrate into any website, enabling instant communication, lead generation, and customer support. With just one click, visitors can call, chat, send inquiries, or request services—without ever leaving the page.
				
				<a href="https://www.stamesoft.com" target="_blank">Learn More.</a>
			</p>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Stames Data Key</th>
                    <td><input type="text" name="stames_floating_data_key" value="<?php echo esc_attr(get_option('stames_floating_data_key')); ?>" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Widget Type</th>
                    <td>
                        <select name="stames_floating_widget_type">
                            <option value="cta" <?php selected(get_option('stames_floating_widget_type', 'cta'), 'cta'); ?>>Call-to-Action</option>
                            <option value="oneclick" <?php selected(get_option('stames_floating_widget_type', 'cta'), 'oneclick'); ?>>One-Click</option>
                        </select>
                    </td>
                </tr>
            </table>
            <div class="stames-btn" style="display: flex; margin-top: 20px">
                <?php submit_button(); ?>
                <p class="submit" style="margin-left: 11px">
                    <a href="<?php echo esc_url(admin_url('admin.php?page=stames-floating-instructions')); ?>" class="button button-secondary">Open Instructions</a>
                </p>
            </div>
        </form>
    </div>
    <?php
}

// Instructions page
function stames_floating_instructions_page() {
    ?>
    <div class="wrap">
        <div style="margin-bottom: 0px;">
            <a href="https://www.stamesoft.com" target="_blank">
                <img src="<?php echo esc_url(plugin_dir_url(__FILE__)) . 'assets/stames-logo.png'; ?>" alt="Stames Logo" style="max-width: 80px;">
            </a>
        </div>
        <h1>Stames Floating Widget - Instructions</h1>
        <p>Follow these steps to install and configure the Stames Floating Widget:</p>
        <ol>
            <li>Go to <strong>Tools > Stames Floating Widget</strong>.</li>
            <li>Enter your <strong>Stames Data Key</strong> and select your preferred widget type.</li>
            <li>Click <strong>Save Changes</strong>.</li>
            <li>The widget will now appear on your website based on your selected option.</li>
        </ol>
        <p>If you experience issues, ensure your Stames account is active and the Data Key is correct.</p>
        <div class="" style="display: flex; margin-top: 20px">
            <a href="https://blog.stamesoft.com/2022/07/17/how-to-install-configure-a-free-stames-web-widget-on-any-website" target="_blank" class="button button-primary">Documentation</a>
            <a href="<?php echo esc_url(admin_url('admin.php?page=stames-floating-widget')); ?>" class="button button-secondary" style="margin-left: 11px">Back to Settings</a>
        </div>
    </div>
    <?php
}
?>